@@ -214,10 +214,8 @@ def collate_metadata(metadata_dict):
             generate_collated_metadata(metadata_dict), key=count_input_paths
         )
     )
-    meta_se = tuple(g for k, g in meta if k == 1)[0]
-    meta_pe = tuple(g for k, g in meta if k == 2)[0]
-    print(meta_pe)
-    raise SystemExit()
+    meta_se = tuple(g for k, g in meta if k == 1)
+    meta_pe = tuple(g for k, g in meta if k == 2)
     return meta_se, meta_pe
 
 
@@ -340,7 +338,7 @@ def get_genotypes(
                             prepare_quasar_input_from_metadata,
                             **prepare_quasar_input_params(temp_dir_name, len(meta_se), pe=False)
                         ),
-                        meta_se
+                        meta_se[0]
                     )
                 else:
                     metadata_quasar_input_paths_se = []
@@ -350,7 +348,7 @@ def get_genotypes(
                             prepare_quasar_input_from_metadata,
                             **prepare_quasar_input_params(temp_dir_name, len(meta_pe), pe=True)
                         ),
-                        meta_pe
+                        meta_pe[0]
                     )
                 else:
                     metadata_quasar_input_paths_pe = []
